@@ -6,7 +6,7 @@ from pydantic import Field, validator
 
 from .account import Account
 from .base import BaseModel
-from .experiment_spec import TaskSpec
+from .experiment_spec import Priority, TaskSpec
 
 
 class CurrentJobStatus(str, Enum):
@@ -101,6 +101,9 @@ class JobKind(str, Enum):
 class Job(BaseModel):
     """
     A :class:`Job` is an execution of a :class:`Task`.
+
+    .. tip::
+        You can check a job's exit code with :data:`job.status.exit_code <JobStatus.exit_code>`.
     """
 
     id: str
@@ -127,3 +130,28 @@ class Job(BaseModel):
 class Jobs(BaseModel):
     data: Optional[Tuple[Job, ...]] = None
     next: Optional[str] = None
+
+
+class CanceledCode(int, Enum):
+    not_set = 0
+    system_preemption = 1
+    user_preemption = 2
+    idle = 3
+
+
+class JobStatusUpdate(BaseModel):
+    scheduled: Optional[bool] = None
+    started: Optional[bool] = None
+    exit_code: Optional[int] = None
+    failed: Optional[bool] = None
+    finalized: Optional[bool] = None
+    canceled: Optional[bool] = None
+    canceled_for: Optional[CanceledCode] = None
+    idle: Optional[bool] = None
+    message: Optional[str] = None
+
+
+class JobPatch(BaseModel):
+    status: Optional[JobStatusUpdate] = None
+    limits: Optional[JobLimits] = None
+    priority: Optional[Priority] = None
