@@ -165,3 +165,13 @@ class DuplicateExperimentError(BeakerError):
 
 class TaskNotFound(BeakerError):
     pass
+
+
+class ChecksumFailedError(BeakerError):
+    """
+    Raised when a downloaded file from a Beaker dataset is corrupted.
+    """
+
+
+class JobFailedError(BeakerError):
+    pass
